auth

package
v0.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrUnknownAuthMethod is returned when an unknown authorization grant type is specified
	ErrUnknownAuthMethod = fmt.Errorf("unknown authorization grant type")
)

Functions

func NewLoginCommand

func NewLoginCommand() *cobra.Command

NewLoginCommand creates a new login command that authenticates users using one of the supported authentication flows: device code, authorization code, or client credentials

func NewLogoutCommand

func NewLogoutCommand() *cobra.Command

NewLogoutCommand creates a new logout command that clears stored credentials

Types

This section is empty.

Jump to