Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidConfigurationKey = errors.New("provided key is not recognized as a valid configuration key.\nuse 'pingcli config list-keys' to view all available keys") ErrNoOptionForKey = errors.New("no option found for the provided configuration key") ErrEmptyKeyForOptionSearch = errors.New("empty key provided for option search, too many matches with options not configured with a koanf key") )
Functions ¶
func ExpandedKoanfKeys ¶ added in v0.6.0
func ExpandedKoanfKeys() (keys []string)
Return a list of all koanf keys from Options Including all substrings of parent keys. For example, the option key export.environmentID adds the keys 'export' and 'export.environmentID' to the list.
func InitAllOptions ¶
func InitAllOptions()
func OptionFromKoanfKey ¶ added in v0.6.0
func ValidateKoanfKey ¶ added in v0.6.0
func ValidateParentKoanfKey ¶ added in v0.6.0
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.