output

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetailedExitCodeWarnLogged added in v0.5.0

func DetailedExitCodeWarnLogged() (bool, error)

func Message

func Message(message string, fields map[string]interface{})

This function outputs white text to supply information to the user.

func PluginError added in v0.7.0

func PluginError(message string, fields map[string]interface{})

This function is used to inform the user a plugin-level error has occurred. These errors should indicate a bug or bad behavior of the plugin.

func SetColorize

func SetColorize()

Set the faith color option based on user configuration

func Success

func Success(message string, fields map[string]interface{})

This function outputs green text to inform the user of success

func SystemError

func SystemError(message string, fields map[string]interface{})

This function is used to inform the user a system-level error has occurred. These errors should indicate a bug or bad behavior of the tool.

func UserError

func UserError(message string, fields map[string]interface{})

This functions is used to inform the user their configuration or input to pingcli has caused an error.

func UserFatal

func UserFatal(message string, fields map[string]interface{})

This functions is used to inform the user their configuration or input to pingcli has caused an fatal error that exits the program immediately.

func Warn

func Warn(message string, fields map[string]interface{})

This function outputs yellow text to inform the user of a warning

Types

This section is empty.

Jump to