Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrUnknownAuthMethod is returned when an unknown authorization grant type is specified ErrUnknownAuthMethod = fmt.Errorf("unknown authorization grant type") )
Functions ¶
func NewLoginCommand ¶
NewLoginCommand creates a new login command that authenticates users using one of the supported authentication flows: device code, authorization code, or client credentials
func NewLogoutCommand ¶
NewLogoutCommand creates a new logout command that clears stored credentials
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.