Documentation
¶
Index ¶
- Constants
- Variables
- func AuthProviderValidValues() []string
- func AuthProviderValidValuesMap() map[string]string
- func ExportFormatValidValues() []string
- func ExportServiceGroupValidValues() []string
- func ExportServicesValidValues() []string
- func ExportServicesValidValuesMap() map[string]string
- func HTTPMethodValidValues() []string
- func LicenseProductValidValues() []string
- func OutputFormatValidValues() []string
- func PingFederateAuthenticationTypeValidValues() []string
- func PingOneAuthenticationTypeValidValues() []string
- func PingOneRegionCodeValidValues() []string
- func RequestServiceValidValues() []string
- func StorageTypeValidValues() []string
- type AuthProvider
- type Bool
- type ExportFormat
- type ExportServiceGroup
- type ExportServices
- func (es *ExportServices) ContainsPingFederateService() bool
- func (es *ExportServices) ContainsPingOneService() bool
- func (es *ExportServices) GetServices() []string
- func (es *ExportServices) Merge(es2 *ExportServices) error
- func (es *ExportServices) Set(servicesStr string) error
- func (es *ExportServices) SetServicesByServiceGroup(serviceGroup *ExportServiceGroup) error
- func (es *ExportServices) String() string
- func (es *ExportServices) Type() string
- type HTTPMethod
- type Header
- type HeaderSlice
- type Int
- type LicenseProduct
- type LicenseVersion
- type OutputFormat
- type PingFederateAuthenticationType
- type PingOneAuthenticationType
- type PingOneRegionCode
- type RequestService
- type StorageLocationType
- type StorageType
- type String
- type StringSlice
- type UUID
Constants ¶
const ( ENUM_EXPORT_SERVICE_PINGONE_PLATFORM string = "pingone-platform" ENUM_EXPORT_SERVICE_PINGONE_AUTHORIZE string = "pingone-authorize" ENUM_EXPORT_SERVICE_PINGONE_SSO string = "pingone-sso" ENUM_EXPORT_SERVICE_PINGONE_MFA string = "pingone-mfa" ENUM_EXPORT_SERVICE_PINGONE_PROTECT string = "pingone-protect" ENUM_EXPORT_SERVICE_PINGFEDERATE string = "pingfederate" )
const ( ENUM_HTTP_METHOD_GET string = "GET" ENUM_HTTP_METHOD_POST string = "POST" ENUM_HTTP_METHOD_PUT string = "PUT" ENUM_HTTP_METHOD_DELETE string = "DELETE" ENUM_HTTP_METHOD_PATCH string = "PATCH" )
const ( ENUM_LICENSE_PRODUCT_PING_ACCESS string = "pingaccess" ENUM_LICENSE_PRODUCT_PING_AUTHORIZE string = "pingauthorize" ENUM_LICENSE_PRODUCT_PING_AUTHORIZE_POLICY_EDITOR string = "pingauthorize-policy-editor" ENUM_LICENSE_PRODUCT_PING_CENTRAL string = "pingcentral" ENUM_LICENSE_PRODUCT_PING_DIRECTORY string = "pingdirectory" ENUM_LICENSE_PRODUCT_PING_DIRECTORY_PROXY string = "pingdirectoryproxy" ENUM_LICENSE_PRODUCT_PING_FEDERATE string = "pingfederate" )
const ( ENUM_OUTPUT_FORMAT_TEXT string = "text" ENUM_OUTPUT_FORMAT_JSON string = "json" )
const ( ENUM_PINGFEDERATE_AUTHENTICATION_TYPE_BASIC string = "basicAuth" ENUM_PINGFEDERATE_AUTHENTICATION_TYPE_ACCESS_TOKEN string = "accessTokenAuth" ENUM_PINGFEDERATE_AUTHENTICATION_TYPE_CLIENT_CREDENTIALS string = "clientCredentialsAuth" )
const ( ENUM_PINGONE_AUTHENTICATION_TYPE_CLIENT_CREDENTIALS string = "client_credentials" ENUM_PINGONE_AUTHENTICATION_TYPE_AUTHORIZATION_CODE string = "authorization_code" ENUM_PINGONE_AUTHENTICATION_TYPE_DEVICE_CODE string = "device_code" ENUM_PINGONE_AUTHENTICATION_TYPE_WORKER string = "worker" )
const ( ENUM_PINGONE_REGION_CODE_AP string = "AP" ENUM_PINGONE_REGION_CODE_AU string = "AU" ENUM_PINGONE_REGION_CODE_CA string = "CA" ENUM_PINGONE_REGION_CODE_EU string = "EU" ENUM_PINGONE_REGION_CODE_NA string = "NA" ENUM_PINGONE_REGION_CODE_SG string = "SG" ENUM_PINGONE_TLD_AP string = "asia" ENUM_PINGONE_TLD_AU string = "com.au" ENUM_PINGONE_TLD_CA string = "ca" ENUM_PINGONE_TLD_EU string = "eu" ENUM_PINGONE_TLD_NA string = "com" ENUM_PINGONE_TLD_SG string = "sg" )
const ( // Values mirror SDK storage types (lowercase) ENUM_STORAGE_TYPE_FILE_SYSTEM string = "file_system" ENUM_STORAGE_TYPE_SECURE_LOCAL string = "secure_local" ENUM_STORAGE_TYPE_SECURE_REMOTE string = "secure_remote" ENUM_STORAGE_TYPE_NONE string = "none" )
const (
ENUM_AUTH_PROVIDER_PINGONE string = "pingone"
)
const (
ENUM_EXPORT_FORMAT_HCL string = "HCL"
)
const (
ENUM_EXPORT_SERVICE_GROUP_PINGONE string = "pingone"
)
const (
ENUM_REQUEST_SERVICE_PINGONE string = "pingone"
)
Variables ¶
var ( ErrCustomTypeNil = errors.New("failed to set value. An internal error occurred") ErrParseBool = errors.New("failed to parse value as bool") ErrParseInt = errors.New("failed to parse value as int") ErrInvalidUUID = errors.New("invalid uuid") ErrInvalidHeaderFormat = errors.New("invalid header format. must be in `key:value` format") ErrDisallowedAuthHeader = errors.New("authorization header is not allowed") ErrUnrecognizedMethod = errors.New("unrecognized http method") ErrUnrecognizedService = errors.New("unrecognized request service") ErrUnrecognizedOutputFormat = errors.New("unrecognized output format") ErrUnrecognizedPingOneRegionCode = errors.New("unrecognized pingone region code") ErrUnrecognizedPingOneAuth = errors.New("unrecognized pingone authorization grant type") ErrUnrecognizedPingFederateAuth = errors.New("unrecognized pingfederate authentication type") ErrUnrecognizedProduct = errors.New("unrecognized license product") ErrInvalidVersionFormat = errors.New("invalid version format, must be 'major.minor'") ErrUnrecognizedFormat = errors.New("unrecognized export format") ErrUnrecognizedServiceGroup = errors.New("unrecognized service group") ErrUnrecognizedExportService = errors.New("unrecognized service") ErrUnrecognizedAuthProvider = errors.New("unrecognized authentication provider") ErrUnrecognizedStorageType = errors.New("unrecognized storage type") )
Functions ¶
func AuthProviderValidValues ¶ added in v0.8.0
func AuthProviderValidValues() []string
AuthProviderValidValues returns a sorted list of all valid authentication provider values
func AuthProviderValidValuesMap ¶ added in v0.8.0
AuthProviderValidValuesMap returns a map of valid auth provider values with lowercase keys
func ExportFormatValidValues ¶
func ExportFormatValidValues() []string
func ExportServiceGroupValidValues ¶ added in v0.5.0
func ExportServiceGroupValidValues() []string
func ExportServicesValidValues ¶
func ExportServicesValidValues() []string
func ExportServicesValidValuesMap ¶ added in v0.8.0
ExportServicesValidValuesMap returns a map of valid export service values with lowercase keys
func HTTPMethodValidValues ¶
func HTTPMethodValidValues() []string
func LicenseProductValidValues ¶ added in v0.7.0
func LicenseProductValidValues() []string
func OutputFormatValidValues ¶
func OutputFormatValidValues() []string
func PingFederateAuthenticationTypeValidValues ¶
func PingFederateAuthenticationTypeValidValues() []string
func PingOneAuthenticationTypeValidValues ¶
func PingOneAuthenticationTypeValidValues() []string
func PingOneRegionCodeValidValues ¶
func PingOneRegionCodeValidValues() []string
func RequestServiceValidValues ¶
func RequestServiceValidValues() []string
func StorageTypeValidValues ¶ added in v0.8.0
func StorageTypeValidValues() []string
Types ¶
type AuthProvider ¶ added in v0.8.0
type AuthProvider string
AuthProvider represents a single supported authentication provider name (pingone)
func (*AuthProvider) ContainsPingOne ¶ added in v0.8.0
func (ap *AuthProvider) ContainsPingOne() bool
ContainsPingOne checks if the PingOne provider is set
func (*AuthProvider) Set ¶ added in v0.8.0
func (ap *AuthProvider) Set(providerStr string) error
Set parses and sets a single authentication provider
func (*AuthProvider) String ¶ added in v0.8.0
func (ap *AuthProvider) String() string
String returns the authentication provider as a string (implements pflag.Value)
func (*AuthProvider) Type ¶ added in v0.8.0
func (ap *AuthProvider) Type() string
Type returns the type string for this custom type (implements pflag.Value)
type ExportFormat ¶
type ExportFormat string
func (*ExportFormat) Set ¶
func (ef *ExportFormat) Set(format string) error
func (*ExportFormat) String ¶
func (ef *ExportFormat) String() string
func (*ExportFormat) Type ¶
func (ef *ExportFormat) Type() string
type ExportServiceGroup ¶ added in v0.5.0
type ExportServiceGroup string
func (*ExportServiceGroup) GetServicesInGroup ¶ added in v0.8.0
func (esg *ExportServiceGroup) GetServicesInGroup() []string
func (*ExportServiceGroup) Set ¶ added in v0.5.0
func (esg *ExportServiceGroup) Set(serviceGroup string) error
func (*ExportServiceGroup) String ¶ added in v0.5.0
func (esg *ExportServiceGroup) String() string
func (*ExportServiceGroup) Type ¶ added in v0.5.0
func (esg *ExportServiceGroup) Type() string
type ExportServices ¶
type ExportServices []string
func (*ExportServices) ContainsPingFederateService ¶
func (es *ExportServices) ContainsPingFederateService() bool
func (*ExportServices) ContainsPingOneService ¶
func (es *ExportServices) ContainsPingOneService() bool
func (*ExportServices) GetServices ¶
func (es *ExportServices) GetServices() []string
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*ExportServices) Merge ¶ added in v0.5.0
func (es *ExportServices) Merge(es2 *ExportServices) error
func (*ExportServices) Set ¶
func (es *ExportServices) Set(servicesStr string) error
func (*ExportServices) SetServicesByServiceGroup ¶ added in v0.5.0
func (es *ExportServices) SetServicesByServiceGroup(serviceGroup *ExportServiceGroup) error
func (*ExportServices) String ¶
func (es *ExportServices) String() string
func (*ExportServices) Type ¶
func (es *ExportServices) Type() string
type HTTPMethod ¶
type HTTPMethod string
func (*HTTPMethod) Set ¶
func (hm *HTTPMethod) Set(httpMethod string) error
func (*HTTPMethod) String ¶
func (hm *HTTPMethod) String() string
func (*HTTPMethod) Type ¶
func (hm *HTTPMethod) Type() string
type HeaderSlice ¶ added in v0.5.0
type HeaderSlice []Header
func (*HeaderSlice) Set ¶ added in v0.5.0
func (h *HeaderSlice) Set(val string) error
func (*HeaderSlice) SetHttpRequestHeaders ¶ added in v0.5.0
func (h *HeaderSlice) SetHttpRequestHeaders(request *http.Request)
func (*HeaderSlice) String ¶ added in v0.5.0
func (h *HeaderSlice) String() string
func (*HeaderSlice) StringSlice ¶ added in v0.5.0
func (h *HeaderSlice) StringSlice() []string
func (*HeaderSlice) Type ¶ added in v0.5.0
func (h *HeaderSlice) Type() string
type LicenseProduct ¶ added in v0.7.0
type LicenseProduct string
func (*LicenseProduct) Set ¶ added in v0.7.0
func (lp *LicenseProduct) Set(product string) error
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*LicenseProduct) String ¶ added in v0.7.0
func (lp *LicenseProduct) String() string
func (*LicenseProduct) Type ¶ added in v0.7.0
func (lp *LicenseProduct) Type() string
type LicenseVersion ¶ added in v0.7.0
type LicenseVersion string
func (*LicenseVersion) Set ¶ added in v0.7.0
func (lv *LicenseVersion) Set(version string) error
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*LicenseVersion) String ¶ added in v0.7.0
func (lv *LicenseVersion) String() string
func (*LicenseVersion) Type ¶ added in v0.7.0
func (lv *LicenseVersion) Type() string
type OutputFormat ¶
type OutputFormat string
func (*OutputFormat) Set ¶
func (o *OutputFormat) Set(outputFormat string) error
func (*OutputFormat) String ¶
func (o *OutputFormat) String() string
func (*OutputFormat) Type ¶
func (o *OutputFormat) Type() string
type PingFederateAuthenticationType ¶
type PingFederateAuthenticationType string
func (*PingFederateAuthenticationType) Set ¶
func (pat *PingFederateAuthenticationType) Set(authType string) error
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*PingFederateAuthenticationType) String ¶
func (pat *PingFederateAuthenticationType) String() string
func (*PingFederateAuthenticationType) Type ¶
func (pat *PingFederateAuthenticationType) Type() string
type PingOneAuthenticationType ¶
type PingOneAuthenticationType string
func (*PingOneAuthenticationType) Set ¶
func (pat *PingOneAuthenticationType) Set(authType string) error
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*PingOneAuthenticationType) String ¶
func (pat *PingOneAuthenticationType) String() string
func (*PingOneAuthenticationType) Type ¶
func (pat *PingOneAuthenticationType) Type() string
type PingOneRegionCode ¶
type PingOneRegionCode string
func (*PingOneRegionCode) Set ¶
func (prc *PingOneRegionCode) Set(regionCode string) error
func (*PingOneRegionCode) String ¶
func (prc *PingOneRegionCode) String() string
func (*PingOneRegionCode) Type ¶
func (prc *PingOneRegionCode) Type() string
type RequestService ¶
type RequestService string
func (*RequestService) Set ¶
func (rs *RequestService) Set(service string) error
Implement pflag.Value interface for custom type in cobra MultiService parameter
func (*RequestService) String ¶
func (rs *RequestService) String() string
func (*RequestService) Type ¶
func (rs *RequestService) Type() string
type StorageLocationType ¶ added in v0.8.1
type StorageLocationType string
StorageLocationType defines the type of storage where credentials are saved
const ( StorageLocationKeychain StorageLocationType = "keychain" StorageLocationFile StorageLocationType = "file" )
type StorageType ¶ added in v0.8.0
type StorageType string
StorageType is a pflag-compatible wrapper for SDK config.StorageType
func (*StorageType) Set ¶ added in v0.8.0
func (st *StorageType) Set(v string) error
func (*StorageType) String ¶ added in v0.8.0
func (st *StorageType) String() string
func (*StorageType) Type ¶ added in v0.8.0
func (st *StorageType) Type() string
type StringSlice ¶
type StringSlice []string
func (*StringSlice) Remove ¶ added in v0.7.0
func (ss *StringSlice) Remove(val string) (bool, error)
func (*StringSlice) Set ¶
func (ss *StringSlice) Set(val string) error
func (*StringSlice) String ¶
func (ss *StringSlice) String() string
func (*StringSlice) StringSlice ¶
func (ss *StringSlice) StringSlice() []string
func (*StringSlice) Type ¶
func (ss *StringSlice) Type() string
Source Files
¶
- auth_provider.go
- bool.go
- errors.go
- export_format.go
- export_service_group.go
- export_services.go
- headers.go
- http_method.go
- int.go
- license_product.go
- license_version.go
- output_format.go
- pingfederate_auth_type.go
- pingone_auth_type.go
- pingone_region_code.go
- request_services.go
- storage_location_type.go
- storage_type.go
- string.go
- string_slice.go
- uuid.go