Documentation
¶
Index ¶
- func DetailedExitCodeWarnLogged() (bool, error)
- func Message(message string, fields map[string]interface{})
- func PluginError(message string, fields map[string]interface{})
- func SetColorize()
- func Success(message string, fields map[string]interface{})
- func SystemError(message string, fields map[string]interface{})
- func UserError(message string, fields map[string]interface{})
- func UserFatal(message string, fields map[string]interface{})
- func Warn(message string, fields map[string]interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DetailedExitCodeWarnLogged ¶ added in v0.5.0
func PluginError ¶ added in v0.7.0
This function is used to inform the user a plugin-level error has occurred. These errors should indicate a bug or bad behavior of the plugin.
func SystemError ¶
This function is used to inform the user a system-level error has occurred. These errors should indicate a bug or bad behavior of the tool.
func UserError ¶
This functions is used to inform the user their configuration or input to pingcli has caused an error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.