Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterLoggerServer(s grpc.ServiceRegistrar, srv LoggerServer)
- func RegisterPingCliCommandServer(s grpc.ServiceRegistrar, srv PingCliCommandServer)
- type Empty
- type LoggerClient
- type LoggerRequest
- func (*LoggerRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LoggerRequest) GetFields() map[string]string
- func (x *LoggerRequest) GetMessage() string
- func (*LoggerRequest) ProtoMessage()
- func (x *LoggerRequest) ProtoReflect() protoreflect.Message
- func (x *LoggerRequest) Reset()
- func (x *LoggerRequest) String() string
- type LoggerServer
- type PingCliCommandClient
- type PingCliCommandConfigurationResponse
- func (*PingCliCommandConfigurationResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PingCliCommandConfigurationResponse) GetExample() string
- func (x *PingCliCommandConfigurationResponse) GetLong() string
- func (x *PingCliCommandConfigurationResponse) GetShort() string
- func (x *PingCliCommandConfigurationResponse) GetUse() string
- func (*PingCliCommandConfigurationResponse) ProtoMessage()
- func (x *PingCliCommandConfigurationResponse) ProtoReflect() protoreflect.Message
- func (x *PingCliCommandConfigurationResponse) Reset()
- func (x *PingCliCommandConfigurationResponse) String() string
- type PingCliCommandRunRequest
- func (*PingCliCommandRunRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PingCliCommandRunRequest) GetArgs() []string
- func (x *PingCliCommandRunRequest) GetLogger() uint32
- func (*PingCliCommandRunRequest) ProtoMessage()
- func (x *PingCliCommandRunRequest) ProtoReflect() protoreflect.Message
- func (x *PingCliCommandRunRequest) Reset()
- func (x *PingCliCommandRunRequest) String() string
- type PingCliCommandServer
- type UnimplementedLoggerServer
- func (UnimplementedLoggerServer) Message(context.Context, *LoggerRequest) (*Empty, error)
- func (UnimplementedLoggerServer) PluginError(context.Context, *LoggerRequest) (*Empty, error)
- func (UnimplementedLoggerServer) Success(context.Context, *LoggerRequest) (*Empty, error)
- func (UnimplementedLoggerServer) UserError(context.Context, *LoggerRequest) (*Empty, error)
- func (UnimplementedLoggerServer) UserFatal(context.Context, *LoggerRequest) (*Empty, error)
- func (UnimplementedLoggerServer) Warn(context.Context, *LoggerRequest) (*Empty, error)
- type UnimplementedPingCliCommandServer
- type UnsafeLoggerServer
- type UnsafePingCliCommandServer
Constants ¶
const ( PingCliCommand_Configuration_FullMethodName = "/PingCliCommand/Configuration" PingCliCommand_Run_FullMethodName = "/PingCliCommand/Run" )
const ( Logger_Message_FullMethodName = "/Logger/Message" Logger_Success_FullMethodName = "/Logger/Success" Logger_Warn_FullMethodName = "/Logger/Warn" Logger_UserError_FullMethodName = "/Logger/UserError" Logger_UserFatal_FullMethodName = "/Logger/UserFatal" Logger_PluginError_FullMethodName = "/Logger/PluginError" )
Variables ¶
var File_pingcli_command_proto protoreflect.FileDescriptor
var Logger_ServiceDesc = grpc.ServiceDesc{ ServiceName: "Logger", HandlerType: (*LoggerServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Message", Handler: _Logger_Message_Handler, }, { MethodName: "Success", Handler: _Logger_Success_Handler, }, { MethodName: "Warn", Handler: _Logger_Warn_Handler, }, { MethodName: "UserError", Handler: _Logger_UserError_Handler, }, { MethodName: "UserFatal", Handler: _Logger_UserFatal_Handler, }, { MethodName: "PluginError", Handler: _Logger_PluginError_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pingcli_command.proto", }
Logger_ServiceDesc is the grpc.ServiceDesc for Logger service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var PingCliCommand_ServiceDesc = grpc.ServiceDesc{ ServiceName: "PingCliCommand", HandlerType: (*PingCliCommandServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Configuration", Handler: _PingCliCommand_Configuration_Handler, }, { MethodName: "Run", Handler: _PingCliCommand_Run_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "pingcli_command.proto", }
PingCliCommand_ServiceDesc is the grpc.ServiceDesc for PingCliCommand service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterLoggerServer ¶
func RegisterLoggerServer(s grpc.ServiceRegistrar, srv LoggerServer)
func RegisterPingCliCommandServer ¶
func RegisterPingCliCommandServer(s grpc.ServiceRegistrar, srv PingCliCommandServer)
Types ¶
type Empty ¶
type Empty struct {
// contains filtered or unexported fields
}
func (*Empty) Descriptor
deprecated
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) ProtoReflect ¶
func (x *Empty) ProtoReflect() protoreflect.Message
type LoggerClient ¶
type LoggerClient interface {
Message(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
Success(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
Warn(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
UserError(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
UserFatal(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
PluginError(ctx context.Context, in *LoggerRequest, opts ...grpc.CallOption) (*Empty, error)
}
LoggerClient is the client API for Logger service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewLoggerClient ¶
func NewLoggerClient(cc grpc.ClientConnInterface) LoggerClient
type LoggerRequest ¶
type LoggerRequest struct {
Message *string `protobuf:"bytes,1,opt,name=message" json:"message,omitempty"`
Fields map[string]string `` /* 132-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*LoggerRequest) Descriptor
deprecated
func (*LoggerRequest) Descriptor() ([]byte, []int)
Deprecated: Use LoggerRequest.ProtoReflect.Descriptor instead.
func (*LoggerRequest) GetFields ¶
func (x *LoggerRequest) GetFields() map[string]string
func (*LoggerRequest) GetMessage ¶
func (x *LoggerRequest) GetMessage() string
func (*LoggerRequest) ProtoMessage ¶
func (*LoggerRequest) ProtoMessage()
func (*LoggerRequest) ProtoReflect ¶
func (x *LoggerRequest) ProtoReflect() protoreflect.Message
func (*LoggerRequest) Reset ¶
func (x *LoggerRequest) Reset()
func (*LoggerRequest) String ¶
func (x *LoggerRequest) String() string
type LoggerServer ¶
type LoggerServer interface {
Message(context.Context, *LoggerRequest) (*Empty, error)
Success(context.Context, *LoggerRequest) (*Empty, error)
Warn(context.Context, *LoggerRequest) (*Empty, error)
UserError(context.Context, *LoggerRequest) (*Empty, error)
UserFatal(context.Context, *LoggerRequest) (*Empty, error)
PluginError(context.Context, *LoggerRequest) (*Empty, error)
// contains filtered or unexported methods
}
LoggerServer is the server API for Logger service. All implementations must embed UnimplementedLoggerServer for forward compatibility.
type PingCliCommandClient ¶
type PingCliCommandClient interface {
Configuration(ctx context.Context, in *Empty, opts ...grpc.CallOption) (*PingCliCommandConfigurationResponse, error)
Run(ctx context.Context, in *PingCliCommandRunRequest, opts ...grpc.CallOption) (*Empty, error)
}
PingCliCommandClient is the client API for PingCliCommand service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPingCliCommandClient ¶
func NewPingCliCommandClient(cc grpc.ClientConnInterface) PingCliCommandClient
type PingCliCommandConfigurationResponse ¶
type PingCliCommandConfigurationResponse struct {
Example *string `protobuf:"bytes,1,opt,name=example" json:"example,omitempty"`
Long *string `protobuf:"bytes,2,opt,name=long" json:"long,omitempty"`
Short *string `protobuf:"bytes,3,opt,name=short" json:"short,omitempty"`
Use *string `protobuf:"bytes,4,opt,name=use" json:"use,omitempty"`
// contains filtered or unexported fields
}
func (*PingCliCommandConfigurationResponse) Descriptor
deprecated
func (*PingCliCommandConfigurationResponse) Descriptor() ([]byte, []int)
Deprecated: Use PingCliCommandConfigurationResponse.ProtoReflect.Descriptor instead.
func (*PingCliCommandConfigurationResponse) GetExample ¶
func (x *PingCliCommandConfigurationResponse) GetExample() string
func (*PingCliCommandConfigurationResponse) GetLong ¶
func (x *PingCliCommandConfigurationResponse) GetLong() string
func (*PingCliCommandConfigurationResponse) GetShort ¶
func (x *PingCliCommandConfigurationResponse) GetShort() string
func (*PingCliCommandConfigurationResponse) GetUse ¶
func (x *PingCliCommandConfigurationResponse) GetUse() string
func (*PingCliCommandConfigurationResponse) ProtoMessage ¶
func (*PingCliCommandConfigurationResponse) ProtoMessage()
func (*PingCliCommandConfigurationResponse) ProtoReflect ¶
func (x *PingCliCommandConfigurationResponse) ProtoReflect() protoreflect.Message
func (*PingCliCommandConfigurationResponse) Reset ¶
func (x *PingCliCommandConfigurationResponse) Reset()
func (*PingCliCommandConfigurationResponse) String ¶
func (x *PingCliCommandConfigurationResponse) String() string
type PingCliCommandRunRequest ¶
type PingCliCommandRunRequest struct {
Args []string `protobuf:"bytes,1,rep,name=args" json:"args,omitempty"`
Logger *uint32 `protobuf:"varint,2,opt,name=logger" json:"logger,omitempty"`
// contains filtered or unexported fields
}
func (*PingCliCommandRunRequest) Descriptor
deprecated
func (*PingCliCommandRunRequest) Descriptor() ([]byte, []int)
Deprecated: Use PingCliCommandRunRequest.ProtoReflect.Descriptor instead.
func (*PingCliCommandRunRequest) GetArgs ¶
func (x *PingCliCommandRunRequest) GetArgs() []string
func (*PingCliCommandRunRequest) GetLogger ¶
func (x *PingCliCommandRunRequest) GetLogger() uint32
func (*PingCliCommandRunRequest) ProtoMessage ¶
func (*PingCliCommandRunRequest) ProtoMessage()
func (*PingCliCommandRunRequest) ProtoReflect ¶
func (x *PingCliCommandRunRequest) ProtoReflect() protoreflect.Message
func (*PingCliCommandRunRequest) Reset ¶
func (x *PingCliCommandRunRequest) Reset()
func (*PingCliCommandRunRequest) String ¶
func (x *PingCliCommandRunRequest) String() string
type PingCliCommandServer ¶
type PingCliCommandServer interface {
Configuration(context.Context, *Empty) (*PingCliCommandConfigurationResponse, error)
Run(context.Context, *PingCliCommandRunRequest) (*Empty, error)
// contains filtered or unexported methods
}
PingCliCommandServer is the server API for PingCliCommand service. All implementations must embed UnimplementedPingCliCommandServer for forward compatibility.
type UnimplementedLoggerServer ¶
type UnimplementedLoggerServer struct{}
UnimplementedLoggerServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedLoggerServer) Message ¶
func (UnimplementedLoggerServer) Message(context.Context, *LoggerRequest) (*Empty, error)
func (UnimplementedLoggerServer) PluginError ¶
func (UnimplementedLoggerServer) PluginError(context.Context, *LoggerRequest) (*Empty, error)
func (UnimplementedLoggerServer) Success ¶
func (UnimplementedLoggerServer) Success(context.Context, *LoggerRequest) (*Empty, error)
func (UnimplementedLoggerServer) UserError ¶
func (UnimplementedLoggerServer) UserError(context.Context, *LoggerRequest) (*Empty, error)
func (UnimplementedLoggerServer) UserFatal ¶
func (UnimplementedLoggerServer) UserFatal(context.Context, *LoggerRequest) (*Empty, error)
func (UnimplementedLoggerServer) Warn ¶
func (UnimplementedLoggerServer) Warn(context.Context, *LoggerRequest) (*Empty, error)
type UnimplementedPingCliCommandServer ¶
type UnimplementedPingCliCommandServer struct{}
UnimplementedPingCliCommandServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPingCliCommandServer) Configuration ¶
func (UnimplementedPingCliCommandServer) Configuration(context.Context, *Empty) (*PingCliCommandConfigurationResponse, error)
func (UnimplementedPingCliCommandServer) Run ¶
func (UnimplementedPingCliCommandServer) Run(context.Context, *PingCliCommandRunRequest) (*Empty, error)
type UnsafeLoggerServer ¶
type UnsafeLoggerServer interface {
// contains filtered or unexported methods
}
UnsafeLoggerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LoggerServer will result in compilation errors.
type UnsafePingCliCommandServer ¶
type UnsafePingCliCommandServer interface {
// contains filtered or unexported methods
}
UnsafePingCliCommandServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PingCliCommandServer will result in compilation errors.